package cn.palmte.work.controller.backend;

import cn.palmte.work.bean.*;
import cn.palmte.work.model.*;
import cn.palmte.work.pojo.ActHisTask;
import cn.palmte.work.service.*;
import cn.palmte.work.utils.FreeMarkerUtil;
import cn.palmte.work.utils.InterfaceUtil;
import cn.palmte.work.utils.Utils;
import cn.palmte.work.utils.excel.ExportUtils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import org.activiti.engine.HistoryService;
import org.activiti.engine.history.HistoricProcessInstance;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.format.datetime.DateFormatter;
import org.springframework.format.number.NumberStyleFormatter;
import org.springframework.stereotype.Controller;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 项目管理功能
 *
 * @author xiongshiyan at 2021/10/29 , contact me with email yanshixiong@126.com or phone 15208384257
 */
@Controller
@RequestMapping("/project")
public class ProjectController extends BaseController {
    private static final Logger logger = LoggerFactory.getLogger(ProjectController.class);
    private static final String PROJECT_ID = "projectId";
    private static final String DETAILS = "details";

    @Autowired
    private DeptService deptService;
    @Autowired
    private ProjectService projectService;
    @Autowired
    private ProjectEstimateService projectEstimateService;
    @Autowired
    private ProjectBudgetService projectBudgetService;
    @Autowired
    private ProjectTaskRecordService projectTaskRecordService;
    @Autowired
    private ActProcInsService actProcInsService;
    @Autowired
    private ProjectInstanceRelationRepository projectInstanceRelationRepository;
    @Autowired
    private ProjectFinalSevice projectFinalSevice;
    @Autowired
    private HistoryService historyService;
    @Autowired
    private ActTaskDefService actTaskDefService;
    @Autowired
    private ProjectSettleService projectSettleService;
    @Autowired
    private ProcurementTypeService procurementTypeService;
    @Autowired
    private ProjectSettleIncomeRepository projectSettleIncomeRepository;
    @Autowired
    private ProjectRepository projectRepository;

    /**
     * 项目列表
     */
    @RequestMapping("/list")
    public String list(@RequestParam(value = "keywords", required = false) String keywords,
                       @RequestParam(value = PAGE_NUMBER, defaultValue = DEFAULT_PAGE_NUMBER) int pageNumber,
                       @RequestParam(value = PAGE_SIZE, defaultValue = DEFAULT_PAGE_SIZE) int pageSize,
                       Map<String, Object> model) {
        //当前登录人的角色类型
        model.put("keywords", keywords);
        model.put("adminId", InterfaceUtil.getAdminId());
        model.put("admin", InterfaceUtil.getAdmin());
        model.put("deptList", deptService.findAll());
        ConcurrentHashMap<String, String> searchInfo = getSearchInfo(keywords, model);
        model.put("pager", projectService.list(searchInfo, pageNumber, pageSize));
        ///
        /*Page<Project> myApproveProjects = projectService.findMyApproveProjects(searchInfo, InterfaceUtil.getAdminId(), 1, Integer.MAX_VALUE);
        model.put("hasApproveProjects", CollectionUtil.isNotEmpty(myApproveProjects.getList()) ? "1" : "0");*/
        return "admin/project_list";
    }

    /**
     * 项目导出
     */
    @RequestMapping("/export")
    public void export(@RequestParam(value = "keywords", required = false) String keywords, HttpServletResponse httpServletResponse) throws IOException {
        Map<String, String> searchInfo = getSearchInfo(keywords);
        downloadHeader(httpServletResponse, Utils.generateExcelName("项目报表"), "application/octet-stream");
        String[] headers = {"项目名称", "项目类型", "项目状态", "审核状态", "当前审核人", "项目创建者", "部门名称", "项目开始时间", "项目结束时间", "最后更新时间"};
        String[] exportColumns = {"name", "typeDesc", "statusDesc", "approveStatusDesc", "approveName", "creatorName", "deptName", "startDateYM", "endDateYM", "lastUpdateTime"};
        ExportUtils.exportToExcel(headers, exportColumns, 1, 10000,
                httpServletResponse.getOutputStream(), (pN, pS) -> projectService.list(searchInfo, pN, pS).getList());
    }


    /**
     * 新增，至项目概算
     */
    @RequestMapping("/add")
    public String add(Map<String, Object> model) {
        Dept one = deptService.findUserDept(InterfaceUtil.getAdmin());
        model.put("dept", one);
        model.put("projectId",-1);
        return "admin/project_estimate_add";
    }

    /**
     * 新增概算项目 保存草稿
     */
    @RequestMapping("/estimateAddSave")
    public String estimateAddSave(Project project, EstimateBean estimateBean, Map<String, Object> model) {
        projectEstimateService.estimateAddSave(project, estimateBean, InterfaceUtil.getAdmin(), ApproveStatusEnum.APPROVAL_UNCOMMIT);
        return "redirect:/project/list";
    }

    /**
     * 新增概算项目 保存并提交审核
     */
    @RequestMapping("/estimateAddSaveAndApprove")
    public String estimateAddSaveAndApprove(Project project, EstimateBean estimateBean, Map<String, Object> model) throws Exception {
        projectEstimateService.estimateAddSaveAndApprove(project, estimateBean, InterfaceUtil.getAdmin());
        return "redirect:/project/list";
    }

    /**
     * 去编辑概算项目页面
     */
    @RequestMapping("/edit")
    public String edit(@RequestParam("id") int id, Map<String, Object> model) {
        Project project = projectService.getProject(id);
        model.put("project", project);
        EstimateBean estimateBean = projectEstimateService.getEstimate(project);
        model.put("estimateBean", estimateBean);
        //freemarker可以利用的静态方法
        model.put("Utils", FreeMarkerUtil.fromStaticPackage("cn.palmte.work.utils.Utils"));
        return "admin/project_estimate_edit";
    }

    /**
     * 编辑概算项目保存
     */
    @RequestMapping("/estimateEditSave")
    public String estimateEditSave(Project project, EstimateBean estimateBean, Map<String, Object> model) {
        Project projectInDb = projectService.getProject(project.getId());
        projectEstimateService.estimateEditSave(project, projectInDb, estimateBean, InterfaceUtil.getAdmin(), ApproveStatusEnum.APPROVAL_UNCOMMIT);
        return "redirect:/project/list";
    }

    /**
     * 编辑概算项目保存并提交审批
     */
    @RequestMapping("/estimateEditSaveAndApprove")
    public String estimateEditSaveAndApprove(Project project, EstimateBean estimateBean, Map<String, Object> model) throws Exception {
        Project projectInDb = projectService.getProject(project.getId());
        projectEstimateService.estimateEditSaveAndApprove(project, projectInDb, estimateBean, InterfaceUtil.getAdmin());
        return "redirect:/project/list";
    }

    /**
     * 进项目预算页面
     */
    @RequestMapping("/budgetEdit")
    public String budget(@RequestParam("id") int id, Map<String, Object> model) {
        Project project = projectService.getProject(id);
        model.put("project", project);

        model.put("planStartStr", project.getPlanStartStr());
        model.put("planStartDate", project.getPlanStartStr());
        model.put("planEndStr", project.getPlanEndStr());
        model.put("planEndDate", project.getPlanEndStr());
        EstimateBean estimateBean = projectEstimateService.getEstimate(project);
        model.put("estimateBean", estimateBean);

        //采购类型
        model.put("procurementTypes", procurementTypeService.allProcurementTypeList());
        BudgetBean budgetBean = projectBudgetService.getBudget(project);
        //预算主页面数据
        model.put("budgetBean", budgetBean);
        //收入明细
        List<ProjectBudgetIncomeDetail> budgetIncomeDetail = projectBudgetService.getBudgetIncomeDetail(project);
        model.put("incomeDetails", budgetIncomeDetail);
        model.put("incomeTotalAmount", projectBudgetService.getBudgetIncomeAmount(project));
        //成本明细
        List<ProjectBudgetCostDetail> budgetCostDetail = projectBudgetService.getBudgetCostDetail(project);
        model.put("costDetails", budgetCostDetail);
        model.put("costTotalAmount", projectBudgetService.getBudgetCostAmount(project));
        //项目管理成本明细
        List<ProjectBudgetCostProjectManageDetail> budgetCostProjectManageDetail = projectBudgetService.getBudgetCostProjectManageDetail(project);
        model.put("costProjectManageDetails", budgetCostProjectManageDetail);
        model.put("costProjectManageTotalAmount", projectBudgetService.getBudgetCostProjectManageAmount(project));
        List<ProjectBudgetPlanDetail> projectBudgetPlanDetails = projectBudgetService.getProjectBudgetPlanDetails(project);
        //资金计划明细
        model.put("projectBudgetPlanDetails", projectBudgetPlanDetails);
        //资金计划总【上面汇总表第一行】
        model.put("projectBudgetPlanDetailTotalTitle", projectBudgetService.getProjectBudgetPlanDetailTotalTitle(project,
                budgetIncomeDetail,
                budgetCostDetail,
                budgetCostProjectManageDetail,
                projectBudgetPlanDetails));
        //资金计划总【上面汇总表第二行】
        model.put("projectBudgetPlanDetailTotal", projectBudgetService.getProjectBudgetPlanDetailTotal(project, projectBudgetPlanDetails));
        //资金计划表中的统计信息【下面资金小表】
        model.put("underwrittenPlanStatistic", projectBudgetService.getProjectUnderwrittenPlanStatisticBean(projectBudgetPlanDetails));
        //现金表
        model.put("cashFlowBean", projectBudgetService.getCashFlowBean(project, projectBudgetPlanDetails));
        //freemarker可以利用的静态方法
        model.put("Utils", FreeMarkerUtil.fromStaticPackage("cn.palmte.work.utils.Utils"));
        return "admin/project_budget_edit";
    }

    /**
     * 进行项目预算保存
     */
    @RequestMapping("/budgetEditSave")
    public String budgetEditSave(Project project, BindingResult bindingResult, BudgetBean budgetBean, Map<String, Object> model) {
        Project projectInDb = projectService.getProject(project.getId());
        projectBudgetService.budgetEditSave(project, projectInDb, budgetBean, InterfaceUtil.getAdmin(), ApproveStatusEnum.APPROVAL_UNCOMMIT);
        return "redirect:/project/list";
    }

    /**
     * 进行项目预算保存并提交审核
     */
    @RequestMapping("/budgetEditSaveAndApprove")
    public String budgetEditSaveAndApprove(Project project, BudgetBean budgetBean, Map<String, Object> model) throws Exception {
        Project projectInDb = projectService.getProject(project.getId());
        projectBudgetService.budgetEditSaveAndApprove(project, projectInDb, budgetBean, InterfaceUtil.getAdmin());
        return "redirect:/project/list";
    }

    /**
     * 保存收入明细
     */
    @RequestMapping("/budgetEditSaveIncomeDetail")
    @ResponseBody
    public ResponseMsg budgetEditSaveIncomeDetail(@RequestBody String body) {
        JSONObject jsonObject = JSON.parseObject(body);
        JSONArray details = jsonObject.getJSONArray(DETAILS);
        List<ProjectBudgetIncomeDetailTemp> detailList = new ArrayList<>(details.size());
        for (int i = 0; i < details.size(); i++) {
            ProjectBudgetIncomeDetailTemp detail = details.getObject(i, ProjectBudgetIncomeDetailTemp.class);
            detailList.add(detail);
        }

        Project project = projectService.getProject(jsonObject.getInteger(PROJECT_ID));

        projectBudgetService.saveBudgetIncomeDetailTemp(project, detailList);

        return ResponseMsg.buildSuccessMsg("成功");
    }

    /**
     * 保存成本明细
     */
    @RequestMapping("/budgetEditSaveCostDetail")
    @ResponseBody
    public ResponseMsg budgetEditSaveCostDetail(@RequestBody String body) {
        JSONObject jsonObject = JSON.parseObject(body);
        JSONArray details = jsonObject.getJSONArray(DETAILS);
        List<ProjectBudgetCostDetailTemp> detailList = new ArrayList<>(details.size());
        for (int i = 0; i < details.size(); i++) {
            ProjectBudgetCostDetailTemp detail = details.getObject(i, ProjectBudgetCostDetailTemp.class);
            detailList.add(detail);
        }

        Project project = projectService.getProject(jsonObject.getInteger(PROJECT_ID));

        projectBudgetService.saveBudgetCostDetailTemp(project, detailList);

        return ResponseMsg.buildSuccessMsg("成功");
    }

    /**
     * 保存项目管理成本明细
     */
    @RequestMapping("/budgetEditSaveCostProjectManageDetail")
    @ResponseBody
    public ResponseMsg budgetEditSaveCostProjectManageDetail(@RequestBody String body) {
        JSONObject jsonObject = JSON.parseObject(body);
        JSONArray details = jsonObject.getJSONArray(DETAILS);
        List<ProjectBudgetCostProjectManageDetailTemp> detailList = new ArrayList<>(details.size());
        for (int i = 0; i < details.size(); i++) {
            ProjectBudgetCostProjectManageDetailTemp detail = details.getObject(i, ProjectBudgetCostProjectManageDetailTemp.class);
            if(detail.getType() == 3 || "3".equals(detail.getName1()) || "8".equals(detail.getName1())) {
                detail.setName(detail.getName2());
                detail.setIsDiy(1);
            } else {
                if ("1".equals(detail.getName1())) {
                    detail.setName("人工费");
                } else if ("2".equals(detail.getName1())) {
                    detail.setName("总部支撑人力费用");
                } else if ("4".equals(detail.getName1())) {
                    detail.setName("人员差旅费");
                } else if ("5".equals(detail.getName1())) {
                    detail.setName("业务费用");
                } else if ("6".equals(detail.getName1())) {
                    detail.setName("商务及专项验收费用");
                } else if ("7".equals(detail.getName1())) {
                    detail.setName("办公费用");
                }
                detail.setIsDiy(0);
            }
            detailList.add(detail);
        }

        Project project = projectService.getProject(jsonObject.getInteger(PROJECT_ID));

        projectBudgetService.saveBudgetCostProjectManageDetailTemp(project, detailList);

        return ResponseMsg.buildSuccessMsg("成功");
    }

    /**
     * 保存项资金计划明细
     */
    @RequestMapping("/budgetEditSaveBudgetPlanDetail")
    @ResponseBody
    public ResponseMsg budgetEditSaveBudgetPlanDetail(@RequestBody String body) {
        JSONObject jsonObject = JSON.parseObject(body);
        JSONArray details = jsonObject.getJSONArray(DETAILS);
        List<ProjectBudgetPlanDetailTemp> detailList = new ArrayList<>(details.size());
        for (int i = 0; i < details.size(); i++) {
            ProjectBudgetPlanDetailTemp detail = details.getObject(i, ProjectBudgetPlanDetailTemp.class);
            detailList.add(detail);
        }

        Project project = projectService.getProject(jsonObject.getInteger(PROJECT_ID));

        projectBudgetService.saveBudgetPlanDetailTemp(project, detailList);

        return ResponseMsg.buildSuccessMsg("成功");
    }


    /**
     * 待我审核项目列表
     */
    @RequestMapping("/listApprove")
    public String listApprove(@RequestParam(value = "keywords", required = false) String keywords,
                              @RequestParam(value = PAGE_NUMBER, defaultValue = DEFAULT_PAGE_NUMBER) int pageNumber,
                              @RequestParam(value = PAGE_SIZE, defaultValue = DEFAULT_PAGE_SIZE) int pageSize,
                              Map<String, Object> model) {
        //当前登录人的角色类型
        model.put("keywords", keywords);
        model.put("deptList", deptService.findAll());
        ConcurrentHashMap<String, String> searchInfo = getSearchInfo(keywords, model);
        model.put("pager", projectService.findMyApproveProjects(searchInfo, InterfaceUtil.getAdminId(), pageNumber, pageSize));
        return "admin/project_list_approve";
    }

    /**
     * 待我审核项目导出
     */
    @RequestMapping("/exportApprove")
    public void exportApprove(@RequestParam(value = "keywords", required = false) String keywords, HttpServletResponse httpServletResponse) throws IOException {
        Map<String, String> searchInfo = getSearchInfo(keywords);
        downloadHeader(httpServletResponse, Utils.generateExcelName("待我审核项目报表"), "application/octet-stream");
        String[] headers = {"项目名称", "项目类型", "项目状态", "审核状态", "当前审核人", "项目创建者", "部门名称", "项目开始时间", "项目结束时间", "最后更新时间"};
        String[] exportColumns = {"name", "typeDesc", "statusDesc", "approveStatusDesc", "approveName", "creatorName", "deptName", "startDate", "endDate", "lastUpdateTime"};
        ExportUtils.exportToExcel(headers, exportColumns, 1, 10000,
                httpServletResponse.getOutputStream(), (pN, pS) -> projectService.findMyApproveProjects(searchInfo, InterfaceUtil.getAdminId(), pN, pS).getList());
    }

    /**
     * 审核页面
     */
    @RequestMapping("/approve")
    public String approve(@RequestParam(value = KEYWORDS, required = false) String keywords,
                          @RequestParam("id") int id, @RequestParam("type") int type,@RequestParam String listFrom,
                          Map<String, Object> model) {
        Project project = projectService.getProject(id);
        model.put("type",type);

        //项目信息
        model.put("adminId", InterfaceUtil.getAdminId());
        model.put("project", project);
        model.put("listFrom", listFrom);

        model.put("planStartStr", project.getPlanStartStr());
        model.put("planStartDate", project.getPlanStartStr());
        model.put("planEndStr", project.getPlanEndStr());
        model.put("planEndDate", project.getPlanEndStr());

        //概算信息
        EstimateBean estimateBean = projectEstimateService.getEstimate(project);
        model.put("estimateBean", estimateBean);

        //预算信息
        BudgetBean budgetBean = projectBudgetService.getBudget(project);
        model.put("procurementTypes", procurementTypeService.allProcurementTypeList());
        model.put("budgetBean", budgetBean);
        //收入明细
        model.put("incomeDetails", projectBudgetService.getBudgetIncomeDetail(project));
        model.put("incomeTotalAmount", projectBudgetService.getBudgetIncomeAmount(project));
        //成本明细
        model.put("costDetails", projectBudgetService.getBudgetCostDetail(project));
        model.put("costTotalAmount", projectBudgetService.getBudgetCostAmount(project));
        //项目管理成本明细
        model.put("costProjectManageDetails", projectBudgetService.getBudgetCostProjectManageDetail(project));
        model.put("costProjectManageTotalAmount", projectBudgetService.getBudgetCostProjectManageAmount(project));
        List<ProjectBudgetPlanDetail> projectBudgetPlanDetails = projectBudgetService.getProjectBudgetPlanDetails(project);
        //资金计划明细
        model.put("projectBudgetPlanDetails", projectBudgetPlanDetails);
        //资金计划总【上面汇总表】
        model.put("projectBudgetPlanDetailTotal", projectBudgetService.getProjectBudgetPlanDetailTotal(project, projectBudgetPlanDetails));
        //资金计划表中的统计信息【下面资金小表】
        model.put("underwrittenPlanStatistic", projectBudgetService.getProjectUnderwrittenPlanStatisticBean(projectBudgetPlanDetails));
        //现金表
        model.put("cashFlowBean", projectBudgetService.getCashFlowBean(project, projectBudgetPlanDetails));

        //结算信息
        model.put("keywords",keywords);
        ConcurrentHashMap<String, String> searchInfo = getSearchInfo(keywords,model);
        String time;
        if (!searchInfo.containsKey("time")) {
            ProjectSettleIncome projectSettleIncome = projectSettleIncomeRepository.findNewByProjectId(id);
            if(null != projectSettleIncome){
                time = projectSettleIncome.getTime();
            }else {
                time = "";
            }
            model.put("time", time);
            model.put("check", 1);
        } else {
            model.put("check", 0);
            time = searchInfo.get("time");
        }
        model.put("formerBean", projectSettleService.getFormerSettle(project, time));
        model.put("monthBean", projectSettleService.getMonthSettleByTime(project, time));
        model.put("currentBean", projectSettleService.getCurrentSettleBytime(project, time));

        //决算信息
        model.put("finalBean", projectFinalSevice.getFinal(project));

        //freemarker可以利用的静态方法
        model.put("Utils", FreeMarkerUtil.fromStaticPackage("cn.palmte.work.utils.Utils"));

        //审核记录
        List<ProjectTaskRecord> list = projectTaskRecordService.list(id);
        if (!list.isEmpty()) {
            model.put("taskRecords", list);
        }

        return "admin/project_approve";
    }

    /**
     * 审批完成任务
     */
    @ResponseBody
    @RequestMapping("/completeTask/{projectId}/{approvetype}")
    public ResponseMsg completeTask(@PathVariable int projectId,@PathVariable int approvetype, @RequestBody String json) {
        return projectService.completeTask(projectId, json,approvetype);
    }


    /**
     * 查看审核流程
     */
    @RequestMapping("/taskRecords/{projectId}")
    public String taskRecords(@PathVariable int projectId, Map<String, Object> model) {
        model.put(PROJECT_ID, projectId);
        List<ProjectTaskRecord> list = projectTaskRecordService.list(projectId);
        if (list != null && !list.isEmpty()) {
            model.put("list", list);
        }

        List<ProjectInstanceRelation> relationList = projectInstanceRelationRepository.findByProjectIdOrderByCreateTimeDesc(projectId);
        if (relationList != null && !relationList.isEmpty()) {
            String procInsId = relationList.get(0).getProcessInsId();

            List<ActHisTask> hisTaskList = actTaskDefService.hisTaskList(procInsId);
            model.put("taskList", hisTaskList);

            HistoricProcessInstance historicProcessInstance = historyService.createHistoricProcessInstanceQuery().processInstanceId(procInsId).singleResult();
            if (historicProcessInstance != null) {
                model.put("procDefName", historicProcessInstance.getProcessDefinitionName());
            }
        }

        return "admin/project_task_record_list";
    }

    /**
     * 流程实列图片
     */
    @RequestMapping("/procInsPng/{projectId}")
    public void png(HttpServletResponse response, @PathVariable(PROJECT_ID) int projectId) throws Exception {
        List<ProjectInstanceRelation> relationList = projectInstanceRelationRepository.findByProjectIdOrderByCreateTimeDesc(projectId);
        if (relationList == null || relationList.isEmpty()) {
            return;
        }
        actProcInsService.createProcInsPng(response, relationList.get(0).getProcessInsId());
    }

    /**
     * 进入选择页面
     */
    @RequestMapping("/selectRoleUser")
    public String selectRoleUser(@RequestParam int projectId, Map<String, Object> model) {
        model.put("project", projectService.getProject(projectId));
        return "admin/project_select_role_user";
    }
    /**
     * 获取当前所有的角色和角色下的用户，根据项目决定是否check
     */
    @RequestMapping("/roleUsers")
    @ResponseBody
    public ResponseMsg roleUsers(@RequestParam int projectId) {
        /*{ id:1, pId:0, name:"随意勾选 1", open:true},
        { id:11, pId:1, name:"随意勾选 1-1", open:true},
        { id:12, pId:1, name:"随意勾选 1-2", open:true},
        { id:2, pId:0, name:"随意勾选 2", checked:true, open:true},
        { id:21, pId:2, name:"随意勾选 2-1"},
        { id:22, pId:2, name:"随意勾选 2-2", open:true},
        { id:23, pId:2, name:"随意勾选 2-3"}*/
        List<ZTreeNode> zTreeNodes = projectService.getZTreeNodes(projectId);
        return ResponseMsg.buildSuccessData(zTreeNodes);
    }

    /**
     * 保存项目与用户的关系
     */
    @RequestMapping("/saveSelectRoleUser")
    @ResponseBody
    public ResponseMsg saveSelectRoleUser(@RequestBody String body) {
        /*{ id:1, pId:0, name:"随意勾选 1", open:true},
        { id:11, pId:1, name:"随意勾选 1-1", open:true},
        { id:12, pId:1, name:"随意勾选 1-2", open:true},
        { id:2, pId:0, name:"随意勾选 2", checked:true, open:true},
        { id:21, pId:2, name:"随意勾选 2-1"},
        { id:22, pId:2, name:"随意勾选 2-2", open:true},
        { id:23, pId:2, name:"随意勾选 2-3"}*/
        JSONObject jsonObject = JSON.parseObject(body);
        Integer projectId = jsonObject.getInteger(PROJECT_ID);
        JSONArray array = jsonObject.getJSONArray("ids");
        String[] ids = new String[array.size()];
        for (int i = 0; i < array.size(); i++) {
            ids[i] = array.getString(i);
        }
        projectService.saveProjectVisible(projectId, ids);
        return ResponseMsg.buildSuccessMsg("成功");
    }


    /**
     * 删除草稿状态下的概算项目
     */
    @GetMapping("/deleteProject/{id}")
    @ResponseBody
    public ResponseMsg deleteProject(@PathVariable int id) {
        return projectService.deleteProject(id);
    }

    @InitBinder
    public void initBinder(WebDataBinder webDataBinder) {
        webDataBinder.addCustomFormatter(new DateFormatter("yyyy-MM-dd"));
        webDataBinder.addCustomFormatter(new NumberStyleFormatter());
    }

    /**
     * 保存项目与用户的关系
     */
    @RequestMapping("/checkName")
    @ResponseBody
    public ResponseMsg checkName(@RequestParam String name,@RequestParam int id) {
        Project project = projectRepository.findByProjectName(name);
        if (project != null && id != project.getId()) {
            return ResponseMsg.buildFailedMsg("失败");
        }
        return ResponseMsg.buildSuccessMsg("成功");
    }

    /**
     * 项目提交审核
     */
    @RequestMapping("/saveApprove")
    @ResponseBody
    public ResponseMsg saveApprove(int id) throws Exception {
        Project project = projectRepository.findOne(id);
        projectService.saveApprove(project, InterfaceUtil.getAdmin());

        return ResponseMsg.buildSuccessMsg("提交成功");
    }
}
